#[non_exhaustive]pub enum BbqError {
Basic(Error),
Busy,
WrongParts,
MaxFrameTooLarge,
}Expand description
Error Type
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Basic(Error)
Errors from LPUart setup
Busy
Could not initialize a new instance as the current instance is already in use
WrongParts
Attempted to create an Rx half with Tx parts, or a Tx half with Rx parts
MaxFrameTooLarge
Requested an [RxMode::MaxFrame] too large for the provided buffer