embassy-mcxa

Crates

git

Versions

mcx-a256

Flavors

LpuartBbqTx

Struct LpuartBbqTx 

pub struct LpuartBbqTx { /* private fields */ }
A bbqueue powered Lpuart TX Half

Implementations

Source

impl LpuartBbqTx

pub fn new(parts: BbqHalfParts, config: BbqConfig) -> Result<Self, BbqError>

Create a new LpuartBbq with only the transmit half

NOTE: Dropping the LpuartBbqTx will permanently leak the TX buffer, DMA channel, and tx pin. Call LpuartBbqTx::teardown to reclaim these resources.

pub async fn write(&mut self, buf: &[u8]) -> Result<usize, BbqError>

Write some data to the outgoing transmit buffer

This method waits until some data is able to be written to the internal buffer, and returns the number of bytes from buf consumed.

This does NOT guarantee all bytes of buf have been buffered, only the amount returned.

This does NOT guarantee the bytes have been written to the wire. See Self::flush().

pub async fn flush(&mut self)

Wait for all bytes in the outgoing buffer to be flushed asynchronously.

When this method completes, the outgoing buffer is empty.

pub fn blocking_flush(&mut self)

Busy wait until all transmitting has completed

When this method completes, the outgoing buffer is empty.

pub fn teardown(self) -> BbqHalfParts

Teardown the Tx handle, reclaiming the parts.